@@ -23,7 +23,7 @@ use rust_htslib::bam;
 use crate::errors::Error;
 use crate::reference;
 use crate::utils;
-use crate::variants::evidence::observation::Strand;
+use crate::variants::evidence::observations::read_observation::Strand;
 use crate::variants::evidence::realignment::edit_distance::EditDistanceCalculation;
 use crate::variants::evidence::realignment::pairhmm::{ReadEmission, ReferenceEmissionParams};
 use crate::variants::types::{AlleleSupport, AlleleSupportBuilder, SingleLocus};
